version_footer

Function version_footer 

pub fn version_footer(version: &str, version_hash: Option<&str>) -> Markup
Renders the version line shown at the bottom of guardian admin pages. version_hash is rendered next to the version in monospace when present.